@@ -1,5 +1,7 @@
 import mimetypes
+import os.path
 from uuid import uuid4
+from webssh.settings import base_dir
 
 
 def encode_multipart_formdata(fields, files):
@@ -39,4 +41,12 @@ def get_content_type(filename):
 
 
 def read_file(path, encoding='utf-8'):
-    return open(path, 'rb').read().decode(encoding)
+    with open(path, 'rb') as f:
+        data = f.read()
+        if encoding is None:
+            return data
+        return data.decode(encoding)
+
+
+def make_tests_data_path(filename):
+    return os.path.join(base_dir, 'tests', 'data', filename)
